@@ -1,4 +1,5 @@
-/* Copyright Abandoned 1996, 1999, 2001 MySQL AB
+/* Copyright (c) 1996, 1999-2004, 2007 MySQL AB
+   Use is subject to license terms
    This file is public domain and comes with NO WARRANTY of any kind */
 
 /* Version numbers for protocol & mysqld */
@@ -9,16 +10,16 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.1.65"
-#define MYSQL_BASE_VERSION		"mysqld-5.1"
+#define MYSQL_SERVER_VERSION		"5.6.12"
+#define MYSQL_BASE_VERSION		"mysqld-5.6"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50165
+#define MYSQL_VERSION_ID		50612
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/tmp/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"MySQL Community Server (GPL)"
+#define MYSQL_COMPILATION_COMMENT	"Source distribution"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
